==> 1.0.1.tar.gz: lib/geidea_secondary_button.dart <==
import 'package:flutter/material.dart';
import 'package:geideadesignframework/style_config.dart';

import 'style_config.dart';

class GeideaSecondaryButton extends StatefulWidget {
  GeideaSecondaryButton(
      {Key key,
        @required this.text,
        @required this.clickCallback,
        this.isDisabled = false,
        this.preTextWidget,
        this.postTextWidget,
        this.textColor,
        this.backgroundColor,
        this.disabledColor,
        this.borderRadius,
        this.fontSize,
        this.borderWidth,
        this.padding,
        this.letterSpacing,
        this.fontWeight})
      : super(key: key);

  final String text;
  final bool isDisabled;
  final VoidCallback clickCallback;
  final Widget preTextWidget;
  final Widget postTextWidget;
  final Color textColor;
  final Color backgroundColor;
  final Color disabledColor;
  final double borderRadius;
  final double fontSize;
  final double borderWidth;
  final double letterSpacing;
  final EdgeInsets padding;
  final FontWeight fontWeight;

  @override
  _GeideaSecondaryButtonState createState() => _GeideaSecondaryButtonState();
}

class _GeideaSecondaryButtonState extends State<GeideaSecondaryButton> {
  bool _isButtonDisabled;

  @override
  void initState() {
    _isButtonDisabled = _isButtonDisabled;
  }

  void _disableButton() {
    setState(() {
      _isButtonDisabled = true;
    });
  }

  @override
  Widget build(BuildContext context) {
    return IgnorePointer(
      ignoring: _isButtonDisabled,
      child: RawMaterialButton(
          onPressed: () {
            if (!_isButtonDisabled) widget.clickCallback();
          },
          padding: widget.padding ?? styleConfig.mainButtonPadding,
          shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(
                  widget.borderRadius ?? styleConfig.borderRadius)),
          elevation: 0,
          disabledElevation: 0,
          fillColor: _isButtonDisabled
              ? (widget.backgroundColor != null ? widget.backgroundColor.withAlpha(77) :
          styleConfig.theme.cursorColor.withAlpha(77))
              : (widget.backgroundColor ?? styleConfig.theme.cursorColor),
          highlightColor: widget.backgroundColor != null ?  widget.backgroundColor.withOpacity(0.3) :
          styleConfig.theme.cursorColor.withOpacity(0.3),
          child: Row(mainAxisAlignment: MainAxisAlignment.center, children: <
              Widget>[
            widget.preTextWidget == null ? Container() : widget.preTextWidget,
            Text(
              widget.text,
              style: TextStyle(
                fontFamily: styleConfig.fontFamily,
                fontSize: widget.fontSize ?? styleConfig.getFontSize('button'),
                fontWeight:
                widget.fontWeight ?? styleConfig.mainButtonFontWeight,
                letterSpacing:
                widget.letterSpacing ?? styleConfig.letterSpacing,
                color: widget.textColor ?? Colors.white,
              ),
            ),
            widget.postTextWidget == null ? Container() : widget.postTextWidget,
          ])),
    );
  }
}

==> 1.0.3.tar.gz: lib/geidea_secondary_button.dart <==
import 'package:flutter/material.dart';
import 'package:geideadesignframework/style_config.dart';

import 'style_config.dart';

class GeideaSecondaryButton extends StatefulWidget {
  GeideaSecondaryButton(
      {Key key,
        @required this.text,
        @required this.clickCallback,
        this.isDisabled = false,
        this.preTextWidget,
        this.postTextWidget,
        this.textColor,
        this.backgroundColor,
        this.disabledColor,
        this.borderRadius,
        this.fontSize,
        this.borderWidth,
        this.padding,
        this.letterSpacing,
        this.fontWeight})
      : super(key: key);

  final String text;
  final bool isDisabled;
  final VoidCallback clickCallback;
  final Widget preTextWidget;
  final Widget postTextWidget;
  final Color textColor;
  final Color backgroundColor;
  final Color disabledColor;
  final double borderRadius;
  final double fontSize;
  final double borderWidth;
  final double letterSpacing;
  final EdgeInsets padding;
  final FontWeight fontWeight;

  @override
  _GeideaSecondaryButtonState createState() => _GeideaSecondaryButtonState();
}

class _GeideaSecondaryButtonState extends State<GeideaSecondaryButton> {

  @override
  Widget build(BuildContext context) {
    return IgnorePointer(
      ignoring: widget.isDisabled,
      child: RawMaterialButton(
          onPressed: () {
            if (!widget.isDisabled) widget.clickCallback();
          },
          padding: widget.padding ?? styleConfig.mainButtonPadding,
          shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(
                  widget.borderRadius ?? styleConfig.borderRadius)),
          elevation: 0,
          disabledElevation: 0,
          fillColor: widget.isDisabled
              ? (widget.backgroundColor != null ? widget.backgroundColor.withAlpha(77) :
          styleConfig.theme.cursorColor.withAlpha(77))
              : (widget.backgroundColor ?? styleConfig.theme.cursorColor),
          highlightColor: widget.backgroundColor != null ?  widget.backgroundColor.withOpacity(0.3) :
          styleConfig.theme.cursorColor.withOpacity(0.3),
          child: Row(mainAxisAlignment: MainAxisAlignment.center, children: <
              Widget>[
            widget.preTextWidget == null ? Container() : widget.preTextWidget,
            Text(
              widget.text,
              style: TextStyle(
                fontFamily: styleConfig.fontFamily,
                fontSize: widget.fontSize ?? styleConfig.getFontSize('button'),
                fontWeight:
                widget.fontWeight ?? styleConfig.mainButtonFontWeight,
                letterSpacing:
                widget.letterSpacing ?? styleConfig.letterSpacing,
                color: widget.textColor ?? Colors.white,
              ),
            ),
            widget.postTextWidget == null ? Container() : widget.postTextWidget,
          ])),
    );
  }
}
